@@ -520,6 +520,12 @@ List swMH(List aList,
     // Print Progress
     if(k % nsims_10pct == 0){
       Rcout << (double)k / nsims_10pct * 10 << " percent done." << std::endl;
+      if(adapt_lambda == 1){
+	Rcout << "Lambda: " << lambda << std::endl;
+      }
+      if(adapt_eprob == 1){
+	Rcout << "Edgecut Probability: " << eprob << std::endl;
+      }
       Rcout << "Metropolis acceptance ratio: "<< (double)decision_counter / (k-1) << std::endl << std::endl;
     }
   
